pub struct u40(/* private fields */);Expand description
40-bit unsigned integer in the range 0..2^40
Implementations
Sourceimpl u40
impl u40
Sourceimpl u40
impl u40
Sourcepub fn checked_add<T>(self, rhs: T) -> Option<Self>
pub fn checked_add<T>(self, rhs: T) -> Option<Self>
Checked integer addition. Computes self + rhs, returning None if
overflow occurred.
Sourcepub fn saturating_add<T>(self, rhs: T) -> Self
pub fn saturating_add<T>(self, rhs: T) -> Self
Saturating integer addition. Computes self + rhs, saturating at the
numeric bounds instead of overflowing.
Sourcepub fn overflowing_add<T>(self, rhs: T) -> (Self, bool)
pub fn overflowing_add<T>(self, rhs: T) -> (Self, bool)
Calculates self + rhs
Returns a tuple of the addition along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Sourcepub fn wrapping_add<T>(self, rhs: T) -> Self
pub fn wrapping_add<T>(self, rhs: T) -> Self
Wrapping (modular) addition. Computes self + rhs, wrapping around at
the boundary of the type.
Sourcepub fn checked_sub<T>(self, rhs: T) -> Option<Self>
pub fn checked_sub<T>(self, rhs: T) -> Option<Self>
Checked integer subtraction. Computes self - rhs, returning None if
overflow occurred.
Sourcepub fn saturating_sub<T>(self, rhs: T) -> Self
pub fn saturating_sub<T>(self, rhs: T) -> Self
Saturating integer subtraction. Computes self - rhs, saturating at the
numeric bounds instead of overflowing.
Sourcepub fn overflowing_sub<T>(self, rhs: T) -> (Self, bool)
pub fn overflowing_sub<T>(self, rhs: T) -> (Self, bool)
Calculates self - rhs
Returns a tuple of the subtraction along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Sourcepub fn wrapping_sub<T>(self, rhs: T) -> Self
pub fn wrapping_sub<T>(self, rhs: T) -> Self
Wrapping (modular) subtraction. Computes self - rhs, wrapping around at
the boundary of the type.
Sourcepub fn checked_mul<T>(self, rhs: T) -> Option<Self>
pub fn checked_mul<T>(self, rhs: T) -> Option<Self>
Checked integer multiplication. Computes self * rhs, returning None if
overflow occurred.
Sourcepub fn saturating_mul<T>(self, rhs: T) -> Self
pub fn saturating_mul<T>(self, rhs: T) -> Self
Saturating integer multiplication. Computes self * rhs, saturating at the
numeric bounds instead of overflowing.
Sourcepub fn overflowing_mul<T>(self, rhs: T) -> (Self, bool)
pub fn overflowing_mul<T>(self, rhs: T) -> (Self, bool)
Calculates self * rhs
Returns a tuple of the multiplication along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Sourcepub fn wrapping_mul<T>(self, rhs: T) -> Self
pub fn wrapping_mul<T>(self, rhs: T) -> Self
Wrapping (modular) multiplication. Computes self * rhs, wrapping around at
the boundary of the type.
pub fn div_rem(self, other: Self) -> Result<(Self, Self), DivError>
Sourceimpl u40
impl u40
Sourcepub fn from_le_bytes(bytes: [u8; 5]) -> Self
pub fn from_le_bytes(bytes: [u8; 5]) -> Self
Create a native endian integer value from its representation as a byte array in little endian.
Sourcepub fn to_le_bytes(self) -> [u8; 5]
pub fn to_le_bytes(self) -> [u8; 5]
Return the memory representation of this integer as a byte array in little-endian byte order.
Sourcepub fn from_be_bytes(bytes: [u8; 5]) -> Self
pub fn from_be_bytes(bytes: [u8; 5]) -> Self
Create a native endian integer value from its representation as a byte array in big endian.
Sourcepub fn to_be_bytes(self) -> [u8; 5]
pub fn to_be_bytes(self) -> [u8; 5]
Return the memory representation of this integer as a byte array in big-endian byte order.
Sourcepub const fn into_isize(self) -> isize
pub const fn into_isize(self) -> isize
Converts into isize type.
Sourcepub const fn into_usize(self) -> usize
pub const fn into_usize(self) -> usize
Converts into usize type.